==> haskell-newtype-generics-0.6.2-56-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-newtype-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 newtype-generics
version:              0.6.2
visibility:           public
id:                   newtype-generics-0.6.2-CLTzajQyjPJJyefxarCTZE
key:                  newtype-generics-0.6.2-CLTzajQyjPJJyefxarCTZE
license:              BSD-3-Clause
maintainer:           Simon Jakobi <simon.jakobi@gmail.com>
author:
    Darius Jahandarie, Conor McBride, João Cristóvão, Simon Jakobi

homepage:             http://github.com/sjakobi/newtype-generics
synopsis:             A typeclass and set of functions for working with newtypes
description:
    Per Conor McBride, the Newtype typeclass represents the packing and unpacking of a newtype,
    and allows you to operate under that newtype with functions such as ala.
    Generics support was added in version 0.4, making this package a full replacement
    for the original newtype package, and a better alternative to newtype-th.

category:             Control
abi:                  1f760d9ad32fffc26fc59889b526318c
exposed:              True
exposed-modules:      Control.Newtype.Generics
import-dirs:          /usr/lib/ghc-9.2.8/site-local/newtype-generics-0.6.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/newtype-generics-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-newtype-generics
hs-libraries:         HSnewtype-generics-0.6.2-CLTzajQyjPJJyefxarCTZE
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-newtype-generics/html/newtype-generics.haddock

haddock-html:         /usr/share/doc/haskell-newtype-generics/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-newtype-generics-0.6.2-58-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-newtype-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 newtype-generics
version:              0.6.2
visibility:           public
id:                   newtype-generics-0.6.2-JT4UWX6eaX3CHrPrVbp5oj
key:                  newtype-generics-0.6.2-JT4UWX6eaX3CHrPrVbp5oj
license:              BSD-3-Clause
maintainer:           Simon Jakobi <simon.jakobi@gmail.com>
author:
    Darius Jahandarie, Conor McBride, João Cristóvão, Simon Jakobi

homepage:             http://github.com/sjakobi/newtype-generics
synopsis:             A typeclass and set of functions for working with newtypes
description:
    Per Conor McBride, the Newtype typeclass represents the packing and unpacking of a newtype,
    and allows you to operate under that newtype with functions such as ala.
    Generics support was added in version 0.4, making this package a full replacement
    for the original newtype package, and a better alternative to newtype-th.

category:             Control
abi:                  1a7c0cc1ee41aef2a68dfc6c2c7b3823
exposed:              True
exposed-modules:      Control.Newtype.Generics
import-dirs:          /usr/lib/ghc-9.2.8/site-local/newtype-generics-0.6.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/newtype-generics-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-newtype-generics
hs-libraries:         HSnewtype-generics-0.6.2-JT4UWX6eaX3CHrPrVbp5oj
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-newtype-generics/html/newtype-generics.haddock

haddock-html:         /usr/share/doc/haskell-newtype-generics/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
